@@ -6,7 +6,6 @@ from   optparse import OptionParser
 import numpy as np
 import tensorflow as tf
 
-import treform.segmentation.lstmWordSegmentationModel as model
 import treform.segmentation.wordSegmentationModelUtil as util
 
 VERBOSE = 0
@@ -38,18 +37,7 @@ if __name__ == '__main__':
 
     # LSTM layer
     # 2 x n_hidden = state_size = (hidden state + cell state)
-    istate = tf.placeholder(tf.float32, [None, 2*n_hidden])
-    weights = {
-        'hidden' : model.weight_variable([n_input, n_hidden]),
-        'out' : model.weight_variable([n_hidden, n_classes])
-    }
-    biases = {
-        'hidden' : model.bias_variable([n_hidden]),
-        'out': model.bias_variable([n_classes])
-    }
-
-    # training
-    y = model.RNN(x, istate, weights, biases, n_hidden, n_steps, n_input, early_stop)
+    y = None
 
     batch_size = 1
     learning_rate = 0.01
@@ -86,6 +74,8 @@ if __name__ == '__main__':
         c_istate = np.zeros((batch_size, 2*n_hidden))
         i = 0
         fid = util.open_file(train_path, 'r')
+        feed = None
+        
         for line in fid :
             line = line.strip()
             if line == "" : continue
@@ -100,7 +90,7 @@ if __name__ == '__main__':
                 print batch_ys
                 print batch_xs
                 '''
-                feed={x: batch_xs, y_: batch_ys, istate: c_istate, early_stop:count}
+                #feed={x: batch_xs, y_: batch_ys, istate: c_istate, early_stop:count}
                 sess.run(optimizer, feed_dict=feed)
                 pos = next_pos
             sys.stderr.write('%s th sentence for %s th iterations ... done\n' % (i, seq))
@@ -111,7 +101,7 @@ if __name__ == '__main__':
             validation_cost = 0
             validation_accuracy = 0
             for validation_xs, validation_ys, count in validation_data :
-                feed={x: validation_xs, y_: validation_ys, istate: c_istate, early_stop:count}
+                #feed={x: validation_xs, y_: validation_ys, istate: c_istate, early_stop:count}
                 validation_cost += sess.run(cost, feed_dict=feed)
                 validation_accuracy += sess.run(accuracy, feed_dict=feed)
             validation_cost /= len(validation_data)
