@@ -8,8 +8,8 @@ from treform.utility.dataset import DataSet
 from treform.utility.num_util import NumUtil
 from treform.utility.char_one_hot_vector import CharOneHotVector
 from treform.utility.datafile_util import DataFileUtil
-from treform.spelling.spelling_error_correction_upgraded import SpellingErrorCorrection
-import tensorflow as tf
+#from treform.spelling.spelling_error_correction_upgraded import SpellingErrorCorrection
+#import tensorflow as tf
 
 
 class BaseSpellingCorrector:
@@ -47,11 +47,11 @@ class DAESpellingCorrector(BaseSpellingCorrector):
     def __call__(self, *args, **kwargs):
         #model_path = "/home/bible/treform/spelling_training/models/spelling_error_correction/spelling_error_correction_model.sentences=3.window_size=10.noise_rate=0.1.n_hidden=100/model"
 
-        tf.compat.v1.disable_v2_behavior()
-        tf.compat.v1.disable_eager_execution()
-
-        detection_graph = tf.compat.v1.get_default_graph()
+        #tf.compat.v1.disable_v2_behavior()
+        #tf.compat.v1.disable_eager_execution()
 
+        #detection_graph = tf.compat.v1.get_default_graph()
+        '''
         with detection_graph.as_default() as default_graph:
 
             with tf.compat.v1.Session() as sess:
@@ -107,5 +107,6 @@ class DAESpellingCorrector(BaseSpellingCorrector):
                         print('"%s"%s "%s"%s' % (chars, dataset.features.shape, original_chars, dataset.labels.shape))
 
                     #print(denoised_sentence)
-
-        return denoised_sentence
+            '''
+        #return denoised_sentence
+        return None
